Skip to contents

Downloads/updates an internal copy of allowable domain values for EQ_DomainValues when domain = NULL

Usage

EQ_UpdateInternalDomainValuesNull()

Value

Returns a data frame of the allowable domain values for the "domain" param of EQ_DomainValues.