Downloads/updates an internal copy of allowable domain values for EQ_DomainValues
Usage
EQ_UpdateInternalDomainValues(api_key = NULL)
Arguments
- api_key
Character string. Users must supply their unique api key to access Expert
Query/ATTAINS web services. To obtain an api, submit the form at:
https://owapps.epa.gov/expertquery/api-key-signup
Value
Returns a data frame of the allowable domain values for the "domain"
param of EQ_DomainValues.