Skip to contents

Downloads/updates an internal copy of allowable domain values for EQ_DomainValues when domain != NULL

Usage

EQ_UpdateInternalDomainValues()

Value

Returns a data frame of the allowable domain values all allowable values of domain excluding NULL. param of EQ_DomainValues.